@@ -4,7 +4,7 @@
    miscutil.h : This file is part of pstoedit
    header declaring misc utility functions
 
-   Copyright (C) 1998 - 2018 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1998 - 2019 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,6 +31,9 @@
 #include I_fstream
 #include I_string_h
 
+#ifdef OS_WIN32_WCE
+#include "netwdm.h"
+#endif
 //lint -efile(451,math.h)
 #include <math.h>
 
@@ -306,11 +309,11 @@ typedef KeyValuePair<RSString,RSString> FontMapping ;
 
 
 //lint -esym(1790,Mapper*)
-#ifndef BUGGYGPP
+//#ifndef BUGGYGPP
 class DLLEXPORT FontMapper: public Mapper<FontMapping>
-#else /* BUGGYGPP */
-class DLLEXPORT FontMapper: public Mapper<FontMapping,RSString,RSString>
-#endif /* BUGGYGPP */
+//#else /* BUGGYGPP */
+//class DLLEXPORT FontMapper: public Mapper<FontMapping,RSString,RSString>
+//#endif /* BUGGYGPP */
 {
 public:
   void readMappingTable(ostream & errstream,const char * filename);
@@ -325,7 +328,7 @@ public:
 DLLEXPORT RSString getRegistryValue(ostream& errstream, const char * typekey, const char * key);
 DLLEXPORT unsigned long P_GetPathToMyself(const char *name, char * returnbuffer, unsigned long buflen);
 DLLEXPORT size_t searchinpath(const char* EnvPath,const char* name, char *returnbuffer,unsigned long buflen);
-DLLEXPORT void errorMessage(const char * text); // display an error message (cerr or msgbox)
+DLLEXPORT void errorMessage(const char * errortext); // display an error message (cerr or msgbox)
 DLLEXPORT void copy_file(istream& infile,ostream& outfile) ;
 DLLEXPORT RSString getOutputFileNameFromPageNumber(const char * const outputFileTemplate, const RSString & pagenumberformatOption, unsigned int pagenumber);
 
