@@ -4,7 +4,7 @@
    poptions.h : This file is part of pstoedit
    program option handling 
 
-   Copyright (C) 1993 - 2018 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2019 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -213,7 +213,7 @@ public:
 
 
   protected:
-	void add(OptionBase * op, const char * const membername) ;
+	void add(OptionBase * op, const char * const membername_p) ;
 
   public:
 	bool expectUnhandled; // whether to expect unhandled arguments
